slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPGetMonitorContext

Gets the monitor context, as set by PEPMonitorSet() for the FIRST monitor only.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPGetMonitorContext(PEP pep,void *ctx)

Not Collective

### Input Parameter

| pep | - eigensolver context obtained from PEPCreate()

### Output Parameter

| ctx | - monitor context

### See Also

PEPMonitorSet(), PEPDefaultMonitor()

### Level

intermediate

### Location

src/pep/interface/pepmon.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages